@@ -12,7 +12,7 @@ Usage::
     session_client: SageMakerRuntimeClient = session.client("sagemaker-runtime")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, IO, TYPE_CHECKING, Union
+from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
 
@@ -21,23 +21,23 @@ __all__ = ("SageMakerRuntimeClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    InternalFailure: Boto3ClientError
-    ModelError: Boto3ClientError
-    ServiceUnavailable: Boto3ClientError
-    ValidationError: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    InternalFailure: Type[Boto3ClientError]
+    ModelError: Type[Boto3ClientError]
+    ServiceUnavailable: Type[Boto3ClientError]
+    ValidationError: Type[Boto3ClientError]
 
 
 class SageMakerRuntimeClient:
     """
-    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -48,7 +48,7 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         """
 
     def invoke_endpoint(
@@ -61,5 +61,5 @@ class SageMakerRuntimeClient:
         TargetModel: str = None,
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         """
